@@ -4,5 +4,7 @@ Hex Graph. The submodules are for different Coodinate representations of Hex Gra
 
 pub mod axial_based;
 pub mod double_coord;
+#[cfg(feature = "hex2d")]
+pub mod hex2d;
 pub mod offset_based;
 pub mod shapes;
