@@ -7,8 +7,10 @@ use crate::unreachable_debug_checked;
 
 /// Shape of the 2d lattice.
 /// It decides the behavior of the coordinate.
-pub trait Shape {
+pub trait Shape: Clone {
+    /// Axis of the lattice.
     type Axis: Axis;
+    /// Coordinate of the lattice graph.
     type Coordinate: Coordinate;
     /// Error to return when [`to_offset`](`Shape::to_offset`) fails.
     /// Should set [`Infallible`](`core::convert::Infallible`) when the graph is looped and never to fail.
@@ -42,7 +44,7 @@ pub trait Shape {
     /// Covert coordinate to index.
     fn to_index(&self, coord: Self::Coordinate) -> Option<usize> {
         let offset = self.to_offset(coord);
-        offset.map(|o| self.offset_to_index(o)).ok()
+        offset.ok().map(|o| self.offset_to_index(o))
     }
     /// Convert index to offset.
     fn index_to_offset(&self, index: usize) -> Offset {
@@ -56,20 +58,26 @@ pub trait Shape {
     }
 
     /// Edge count of horizontal. May differ by the axis info.
+    #[deprecated]
     fn horizontal_edge_size(&self, _axis: Self::Axis) -> usize {
         self.horizontal()
     }
     /// Edge count of vertical. May differ by the axis info.
+    #[deprecated]
     fn vertical_edge_size(&self, _axis: Self::Axis) -> usize {
         self.vertical()
     }
-    /// Move coordinate to direction.
+    /// Move coordinates to the next coordinate in the direction.
+    /// Coordinate should be a valid coordinate and should be checked before using `move_coord`.
+    /// This is because the target coordinate might be valid even thought the souce coord is invalid,
+    /// and some code validate the direction by moveing the coord.
     fn move_coord(
         &self,
         coord: Self::Coordinate,
         dir: <Self::Axis as Axis>::Direction,
     ) -> Result<Self::Coordinate, Self::CoordinateMoveError>;
-    /// Move coordinate to direction.
+    /// Move coordinates to the next coordinate in the direction.
+    /// Caller should be sure that the source and the target coord is valid coord.
     unsafe fn move_coord_unchecked(
         &self,
         coord: Self::Coordinate,
@@ -78,25 +86,19 @@ pub trait Shape {
         self.move_coord(coord, dir)
             .unwrap_or_else(|_| unreachable_debug_checked())
     }
-    ///Check whether coordinate is in neighbor.
-    fn is_neighbor(&self, a: Self::Coordinate, b: Self::Coordinate) -> bool
-    where
-        Self::Coordinate: PartialEq,
-    {
+    ///Check whether two coordinate is in neighbor.
+    fn is_neighbor(&self, a: Self::Coordinate, b: Self::Coordinate) -> bool {
         self.get_direction(a, b).is_some()
     }
-    ///Get direction if two coordiante is neighbor.
+    ///Get direction if two coordiante is in neighbor.
     fn get_direction(
         &self,
         source: Self::Coordinate,
         target: Self::Coordinate,
-    ) -> Option<<Self::Axis as Axis>::Direction>
-    where
-        Self::Coordinate: PartialEq,
-    {
+    ) -> Option<<Self::Axis as Axis>::Direction> {
         let a = source;
         let b = target;
-        for i in 0..<Self::Axis as Axis>::DIRECTED_COUNT {
+        for i in 0..<Self::Axis as Axis>::UNDIRECTED_COUNT {
             let d = unsafe { <Self::Axis as Axis>::Direction::dir_from_index_unchecked(i) };
             let c = self.move_coord(a, d.clone());
             if let Ok(c) = c {
@@ -135,14 +137,6 @@ impl<S: Shape> Shape for &S {
         (*self).vertical()
     }
 
-    fn horizontal_edge_size(&self, axis: Self::Axis) -> usize {
-        (*self).horizontal_edge_size(axis)
-    }
-
-    fn vertical_edge_size(&self, axis: Self::Axis) -> usize {
-        (*self).vertical_edge_size(axis)
-    }
-
     fn move_coord(
         &self,
         coord: Self::Coordinate,
@@ -204,8 +198,8 @@ pub trait Axis: Copy + PartialEq {
     const COUNT: usize;
     /// Whether it is Directed or not.
     const DIRECTED: bool;
-    /// If this axis is not directed, it is doubled, otherwise same as `COUNT`.
-    const DIRECTED_COUNT: usize = if Self::DIRECTED {
+    /// Number of direction. If this axis is not directed, it is `COUNT * 2`, otherwise `COUNT`.
+    const UNDIRECTED_COUNT: usize = if Self::DIRECTED {
         Self::COUNT
     } else {
         Self::COUNT * 2
@@ -227,6 +221,8 @@ pub trait Axis: Copy + PartialEq {
     fn foward(self) -> Self::Direction;
     /// To backward direction. It reverses when Axis is `DIRECTED`.
     fn backward(self) -> Self::Direction;
+    /// Check the direction is forward for this axis.
+    /// Returns true if the direction is `DIRECTED` is `true`, or the index of the axis and direction matches.
     fn is_forward_direction(dir: &Self::Direction) -> bool {
         Self::DIRECTED || dir.dir_to_index() == Self::from_direction(dir.clone()).to_index()
     }
@@ -237,8 +233,11 @@ pub trait Axis: Copy + PartialEq {
 /// Direction of axis. It tells which direction is connected to node.
 pub trait AxisDirection: Clone {
     /// Check this match whith [`Axis`]. It will always return true when `Axis` is directed.
+    #[deprecated(note = "Use Axis::is_forward_direction instead.")]
     fn is_forward(&self) -> bool;
     /// Check this doesn't match whith [`Axis`]. It will always return false when `Axis` is directed.
+    #[deprecated(note = "Use !Axis::is_forward_direction instead.")]
+    #[allow(deprecated)]
     fn is_backward(&self) -> bool {
         !self.is_forward()
     }
@@ -274,13 +273,15 @@ where
     }
 }
 
-/// Default Implimention of [`AxisDirection`] when [`Axis::DIRECTED`] is false.
+/// Implimention of [`AxisDirection`] when [`Axis::DIRECTED`] is false.
 #[derive(Debug, Clone, Copy, Hash, PartialEq, Eq, PartialOrd, Ord)]
+#[deprecated]
 pub enum Direction<T> {
     Foward(T),
     Backward(T),
 }
 
+#[allow(deprecated)]
 impl<T: Axis> AxisDirection for Direction<T> {
     fn is_forward(&self) -> bool {
         match self {
@@ -327,50 +328,60 @@ pub struct Offset {
 }
 
 impl Offset {
+    /// Create a new offset.
     pub fn new(h: usize, v: usize) -> Self {
         Offset {
             horizontal: h.into(),
             vertical: v.into(),
         }
     }
+    /// Get a horizontal.
     pub fn horizontal(&self) -> usize {
         self.horizontal
     }
+    /// Get a vertical.
     pub fn vertical(&self) -> usize {
         self.vertical
     }
-    pub fn add_x(&self, x: usize) -> Self {
+    #[inline]
+    pub(crate) fn add_x(&self, x: usize) -> Self {
         Offset::new(self.horizontal + x, self.vertical)
     }
-    pub fn add_y(&self, y: usize) -> Self {
+    #[inline]
+    pub(crate) fn add_y(&self, y: usize) -> Self {
         Offset::new(self.horizontal, self.vertical + y)
     }
-    pub fn set_x(&self, x: usize) -> Self {
+    #[inline]
+    pub(crate) fn set_x(&self, x: usize) -> Self {
         Offset::new(x, self.vertical)
     }
-    pub fn set_y(&self, y: usize) -> Self {
-        Offset::new(self.horizontal, y)
-    }
-    pub fn sub_x(&self, x: usize) -> Option<Self> {
+    // pub(crate) fn set_y(&self, y: usize) -> Self {
+    //     Offset::new(self.horizontal, y)
+    // }
+    #[inline]
+    pub(crate) fn sub_x(&self, x: usize) -> Option<Self> {
         Some(Offset::new(self.horizontal.checked_sub(x)?, self.vertical))
     }
-    pub fn sub_y(&self, y: usize) -> Option<Self> {
+    #[inline]
+    pub(crate) fn sub_y(&self, y: usize) -> Option<Self> {
         Some(Offset::new(self.horizontal, self.vertical.checked_sub(y)?))
     }
-    pub unsafe fn sub_x_unchecked(&self, x: usize) -> Self {
-        Offset::new(self.horizontal - x, self.vertical)
-    }
-    pub unsafe fn sub_y_unchecked(&self, y: usize) -> Self {
-        Offset::new(self.horizontal, self.vertical - y)
-    }
-    pub fn check_x(&self, x_max: usize) -> Option<Self> {
+    // pub(crate) unsafe fn sub_x_unchecked(&self, x: usize) -> Self {
+    //     Offset::new(self.horizontal - x, self.vertical)
+    // }
+    // pub(crate) unsafe fn sub_y_unchecked(&self, y: usize) -> Self {
+    //     Offset::new(self.horizontal, self.vertical - y)
+    // }
+    #[inline]
+    pub(crate) fn check_x(&self, x_max: usize) -> Option<Self> {
         if self.horizontal < x_max {
             Some(*self)
         } else {
             None
         }
     }
-    pub fn check_y(&self, y_max: usize) -> Option<Self> {
+    #[inline]
+    pub(crate) fn check_y(&self, y_max: usize) -> Option<Self> {
         if self.vertical < y_max {
             Some(*self)
         } else {
